@@ -1,26 +1,23 @@
-/* Copyright (c) 2002-2017 Pigeonhole authors, see the included COPYING file
- */
-
-#ifndef __SIEVE_RUNTIME_H
-#define __SIEVE_RUNTIME_H
+#ifndef SIEVE_RUNTIME_H
+#define SIEVE_RUNTIME_H
 
 #include "sieve-common.h"
+#include "sieve-execute.h"
 
 /*
  * Runtime environment
  */
 
 struct sieve_runtime_env {
+	const struct sieve_execute_env *exec_env;
+	struct event *event;
+
 	/* Interpreter */
-	struct sieve_instance *svinst;
 	struct sieve_interpreter *interp;
-	enum sieve_execute_flags flags;
 	struct sieve_error_handler *ehandler;
 
 	/* Executing script */
 	struct sieve_script *script;
-	const struct sieve_script_env *scriptenv;
-	struct sieve_exec_status *exec_status;
 
 	/* Executing binary */
 	struct sieve_binary *sbin;
@@ -31,7 +28,6 @@ struct sieve_runtime_env {
 	const struct sieve_operation *oprtn;
 
 	/* Tested message */
-	const struct sieve_message_data *msgdata;
 	struct sieve_message_context *msgctx;
 
 	/* Filter result */
@@ -41,4 +37,4 @@ struct sieve_runtime_env {
 	struct sieve_runtime_trace *trace;
 };
 
-#endif /* __SIEVE_RUNTIME_H */
+#endif
